@@ -6,6 +6,8 @@
  */
 
 #include "aclmanager.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "aclentrydialog_p.h"
 #include "aclmodifyjob.h"
 #include "aclutils_p.h"
@@ -303,7 +305,7 @@ public:
         const QMap<QByteArray, KIMAP::Acl::Rights> rights = attribute->rights();
 
         QString resource = collection.resource();
-        if (resource.contains(QLatin1String("akonadi_kolabproxy_resource"))) {
+        if (resource.contains("akonadi_kolabproxy_resource"_L1)) {
             const QString basename = Akonadi::ServerManager::agentServiceName(Akonadi::ServerManager::Agent, QStringLiteral("akonadi_kolabproxy_resource"));
 
             QDBusInterface interface(basename, QStringLiteral("/KolabProxy"));
