@@ -9,9 +9,9 @@
 #include "mailutil.h"
 #include <PimCommon/PimUtil>
 
-#include <AgentInstance>
-#include <AkonadiCore/AgentManager>
-#include <AkonadiCore/ServerManager>
+#include <Akonadi/AgentInstance>
+#include <Akonadi/AgentManager>
+#include <Akonadi/ServerManager>
 
 bool PimCommon::MailUtil::isImapFolder(const Akonadi::Collection &col, bool &isOnline)
 {
